@@ -493,7 +493,7 @@ class HwndWrapper(BaseWrapper):
         (e.g. VK_LEFT, VK_DELETE), a KeySequenceError is raised. Consider using
         the method send_keystrokes for such input.
         """
-        input_locale_id = ctypes.windll.User32.GetKeyboardLayout(0)
+        input_locale_id = win32functions.GetKeyboardLayout(0)
         keys = keyboard.parse_keys(chars, with_spaces, with_tabs, with_newlines)
 
         for key in keys:
@@ -506,7 +506,7 @@ class HwndWrapper(BaseWrapper):
 
             if unicode_char:
                 _, char = key_info[:2]
-                vk = ctypes.windll.User32.VkKeyScanExW(char, input_locale_id) & 0xFF
+                vk = win32functions.VkKeyScanExW(chr(char), input_locale_id) & 0xFF
                 scan = keyboard.MapVirtualKey(vk, 0)
             else:
                 vk, scan = key_info[:2]
@@ -541,22 +541,21 @@ class HwndWrapper(BaseWrapper):
 
         .. _`type_keys`: pywinauto.base_wrapper.html#pywinauto.base_wrapper.BaseWrapper.type_keys
         """
-        user32 = ctypes.windll.User32
         PBYTE256 = ctypes.c_ubyte * 256
 
         win32gui.SendMessage(self.handle, win32con.WM_ACTIVATE,
                              win32con.WA_ACTIVE, 0)
-        target_thread_id = user32.GetWindowThreadProcessId(self.handle, None)
-        current_thread_id = win32api.GetCurrentThreadId()
-        attach_success = user32.AttachThreadInput(target_thread_id, current_thread_id, True) != 0
+        target_thread_id = win32functions.GetWindowThreadProcessId(self.handle, None)
+        current_thread_id = win32functions.GetCurrentThreadId()
+        attach_success = win32functions.AttachThreadInput(target_thread_id, current_thread_id, True) != 0
         if not attach_success:
             warnings.warn('Failed to attach app\'s thread to the current thread\'s message queue',
                           UserWarning, stacklevel=2)
 
         keyboard_state_stack = [PBYTE256()]
-        user32.GetKeyboardState(ctypes.byref(keyboard_state_stack[-1]))
+        win32functions.GetKeyboardState(keyboard_state_stack[-1])
 
-        input_locale_id = ctypes.windll.User32.GetKeyboardLayout(0)
+        input_locale_id = win32functions.GetKeyboardLayout(0)
         context_code = 0
 
         keys = keyboard.parse_keys(keystrokes, with_spaces, with_tabs, with_newlines)
@@ -578,8 +577,8 @@ class HwndWrapper(BaseWrapper):
                 shift_state = 0
                 unicode_codepoint = flags & keyboard.KEYEVENTF_UNICODE != 0
                 if unicode_codepoint:
-                    char = scan
-                    vk_with_flags = user32.VkKeyScanExW(char, input_locale_id)
+                    char = chr(scan)
+                    vk_with_flags = win32functions.VkKeyScanExW(char, input_locale_id)
                     vk = vk_with_flags & 0xFF
                     shift_state = (vk_with_flags & 0xFF00) >> 8
                     scan = keyboard.MapVirtualKey(vk, 0)
@@ -602,8 +601,8 @@ class HwndWrapper(BaseWrapper):
                         context_code << 29 |
                         0 << 31)
 
-                    user32.SetKeyboardState(ctypes.byref(keyboard_state_stack[-1]))
-                    win32api.PostMessage(self.handle, down_msg, vk, lparam)
+                    win32functions.SetKeyboardState(keyboard_state_stack[-1])
+                    win32functions.PostMessage(self.handle, down_msg, vk, lparam)
                     if vk == keyboard.VK_MENU:
                         context_code = 1
 
@@ -621,8 +620,8 @@ class HwndWrapper(BaseWrapper):
                         1 << 30 |
                         1 << 31)
 
-                    win32api.PostMessage(self.handle, up_msg, vk, lparam)
-                    user32.SetKeyboardState(ctypes.byref(keyboard_state_stack[-1]))
+                    win32functions.PostMessage(self.handle, up_msg, vk, lparam)
+                    win32functions.SetKeyboardState(keyboard_state_stack[-1])
 
                     if vk == keyboard.VK_MENU:
                         context_code = 0
@@ -636,10 +635,10 @@ class HwndWrapper(BaseWrapper):
                               UserWarning, stacklevel=2)
             else:
                 warnings.warn(e.strerror, UserWarning, stacklevel=2)
-            user32.SetKeyboardState(ctypes.byref(keyboard_state_stack[0]))
+            win32functions.SetKeyboardState(keyboard_state_stack[0])
 
         if attach_success:
-            user32.AttachThreadInput(target_thread_id, current_thread_id, False)
+            win32functions.AttachThreadInput(target_thread_id, current_thread_id, False)
 
     # -----------------------------------------------------------
     def send_message_timeout(
@@ -1256,7 +1255,7 @@ class HwndWrapper(BaseWrapper):
         """Return a handle to the active window within the process"""
         gui_info = win32structures.GUITHREADINFO()
         gui_info.cbSize = ctypes.sizeof(gui_info)
-        window_thread_id, _ = win32process.GetWindowThreadProcessId(int(self.handle))
+        window_thread_id = win32functions.GetWindowThreadProcessId(self.handle, None)
         ret = win32functions.GetGUIThreadInfo(
             window_thread_id,
             ctypes.byref(gui_info))
@@ -1278,7 +1277,7 @@ class HwndWrapper(BaseWrapper):
         """
         gui_info = win32structures.GUITHREADINFO()
         gui_info.cbSize = ctypes.sizeof(gui_info)
-        window_thread_id, _ = win32process.GetWindowThreadProcessId(self.handle)
+        window_thread_id = win32functions.GetWindowThreadProcessId(self.handle, None)
         ret = win32functions.GetGUIThreadInfo(
             window_thread_id,
             ctypes.byref(gui_info))
@@ -1335,7 +1334,7 @@ class HwndWrapper(BaseWrapper):
 
     def has_keyboard_focus(self):
         """Check the keyboard focus on this control."""
-        control_thread = win32process.GetWindowThreadProcessId(self.handle)[0]
+        control_thread = win32functions.GetWindowThreadProcessId(self.handle, None)
         win32process.AttachThreadInput(control_thread, win32api.GetCurrentThreadId(), 1)
         focused = win32gui.GetFocus()
         win32process.AttachThreadInput(control_thread, win32api.GetCurrentThreadId(), 0)
@@ -1346,9 +1345,9 @@ class HwndWrapper(BaseWrapper):
 
     def set_keyboard_focus(self):
         """Set the keyboard focus to this control."""
-        control_thread = win32process.GetWindowThreadProcessId(self.handle)[0]
+        control_thread = win32functions.GetWindowThreadProcessId(self.handle, None)
         win32process.AttachThreadInput(control_thread, win32api.GetCurrentThreadId(), 1)
-        win32gui.SetFocus(self.handle)
+        win32functions.SetFocus(self.handle)
         win32process.AttachThreadInput(control_thread, win32api.GetCurrentThreadId(), 0)
 
         win32functions.WaitGuiThreadIdle(self.handle)
@@ -1602,12 +1601,13 @@ class DialogWrapper(HwndWrapper):
         #win32defines.SMTO_BLOCK)
 
         # get a handle we can wait on
-        _, pid = win32process.GetWindowThreadProcessId(int(self.handle))
+        pid = ctypes.c_ulong()
+        win32functions.GetWindowThreadProcessId(self.handle, ctypes.byref(pid))
         try:
             process_wait_handle = win32api.OpenProcess(
                 win32con.SYNCHRONIZE | win32con.PROCESS_TERMINATE,
                 0,
-                pid)
+                pid.value)
         except win32gui.error:
             return True # already closed
 
@@ -1723,7 +1723,7 @@ def _perform_click(
     # figure out the flags and pack coordinates
     flags, click_point = _calc_flags_and_coords(pressed, coords)
 
-    #control_thread = win32functions.GetWindowThreadProcessId(ctrl, 0)
+    #control_thread = win32functions.GetWindowThreadProcessId(ctrl, None)
     #win32functions.AttachThreadInput(win32functions.GetCurrentThreadId(), control_thread, win32defines.TRUE)
     # TODO: check return value of AttachThreadInput properly
 
